==> huaweicloudsdkelb-3.0.54-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/list_pools_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPoolsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'page_info': 'PageInfo',
        'pools': 'list[Pool]'
    }

    attribute_map = {
        'request_id': 'request_id',
        'page_info': 'page_info',
        'pools': 'pools'
    }

    def __init__(self, request_id=None, page_info=None, pools=None):
        """ListPoolsResponse - a model defined in huaweicloud sdk"""
        
        super(ListPoolsResponse, self).__init__()

        self._request_id = None
        self._page_info = None
        self._pools = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if page_info is not None:
            self.page_info = page_info
        if pools is not None:
            self.pools = pools

    @property
    def request_id(self):
        """Gets the request_id of this ListPoolsResponse.

        请求ID。  注：自动生成 。

        :return: The request_id of this ListPoolsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this ListPoolsResponse.

        请求ID。  注：自动生成 。

        :param request_id: The request_id of this ListPoolsResponse.
        :type: str
        """
        self._request_id = request_id

    @property
    def page_info(self):
        """Gets the page_info of this ListPoolsResponse.


        :return: The page_info of this ListPoolsResponse.
        :rtype: PageInfo
        """
        return self._page_info

    @page_info.setter
    def page_info(self, page_info):
        """Sets the page_info of this ListPoolsResponse.


        :param page_info: The page_info of this ListPoolsResponse.
        :type: PageInfo
        """
        self._page_info = page_info

    @property
    def pools(self):
        """Gets the pools of this ListPoolsResponse.

        后端服务器组列表。

        :return: The pools of this ListPoolsResponse.
        :rtype: list[Pool]
        """
        return self._pools

    @pools.setter
    def pools(self, pools):
        """Sets the pools of this ListPoolsResponse.

        后端服务器组列表。

        :param pools: The pools of this ListPoolsResponse.
        :type: list[Pool]
        """
        self._pools = pools

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPoolsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.0.81-py2.py3-none-any.whl: huaweicloudsdkelb/v3/model/list_pools_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListPoolsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'request_id': 'str',
        'page_info': 'PageInfo',
        'pools': 'list[Pool]'
    }

    attribute_map = {
        'request_id': 'request_id',
        'page_info': 'page_info',
        'pools': 'pools'
    }

    def __init__(self, request_id=None, page_info=None, pools=None):
        """ListPoolsResponse - a model defined in huaweicloud sdk"""
        
        super(ListPoolsResponse, self).__init__()

        self._request_id = None
        self._page_info = None
        self._pools = None
        self.discriminator = None

        if request_id is not None:
            self.request_id = request_id
        if page_info is not None:
            self.page_info = page_info
        if pools is not None:
            self.pools = pools

    @property
    def request_id(self):
        """Gets the request_id of this ListPoolsResponse.

        请求ID。  注：自动生成 。

        :return: The request_id of this ListPoolsResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this ListPoolsResponse.

        请求ID。  注：自动生成 。

        :param request_id: The request_id of this ListPoolsResponse.
        :type: str
        """
        self._request_id = request_id

    @property
    def page_info(self):
        """Gets the page_info of this ListPoolsResponse.


        :return: The page_info of this ListPoolsResponse.
        :rtype: PageInfo
        """
        return self._page_info

    @page_info.setter
    def page_info(self, page_info):
        """Sets the page_info of this ListPoolsResponse.


        :param page_info: The page_info of this ListPoolsResponse.
        :type: PageInfo
        """
        self._page_info = page_info

    @property
    def pools(self):
        """Gets the pools of this ListPoolsResponse.

        后端服务器组列表。

        :return: The pools of this ListPoolsResponse.
        :rtype: list[Pool]
        """
        return self._pools

    @pools.setter
    def pools(self, pools):
        """Sets the pools of this ListPoolsResponse.

        后端服务器组列表。

        :param pools: The pools of this ListPoolsResponse.
        :type: list[Pool]
        """
        self._pools = pools

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListPoolsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
